@@ -30,7 +30,7 @@
 #define CONFIG_PARAM_HW_VER             2
 // update here our own default sw version:
 #define D_CONFIG_PARAM_SW_MAJOR           2
-#define D_CONFIG_PARAM_SW_MINOR           1
+#define D_CONFIG_PARAM_SW_MINOR           4
 #define CONFIG_PARAM_VTARGET 50
 #define CONFIG_PARAM_VADJUST 25
 #define CONFIG_PARAM_OSC_PSCALE 2
@@ -600,6 +600,41 @@ void programcmd(unsigned char seqnum)
         
 }
 
+// Read a max of 2 digits from the serial line
+// return value of -1 means no change (user just hit return)
+signed char terminalmode_readnum(unsigned char iswin){
+        unsigned char ch;
+        unsigned char lineendcnt=1;
+        unsigned char digits=2; // you can enter max 2 digits
+        signed char rval=-1;
+	if (iswin){
+		// we expect \r\n as line end
+		lineendcnt=2;
+	}
+	ch=uart_getchar();
+	while(ch != '\r' && ch !='\n' && digits){
+		if ((ch >= '0') && (ch <= '9')){
+			if (rval==-1){
+				rval=0;
+			}
+			uart_sendchar(ch); // echo number back to terminal
+			rval=rval*10 + (ch  - (unsigned char)'0');
+			digits--;
+		}
+		ch=uart_getchar();
+	}
+	// user just pressed return or enter just 1 digit
+	if (ch == '\r' || ch == '\n'){
+		lineendcnt--;
+	}
+	// get \n or \r\n after a number was entered:
+	while(lineendcnt){
+		ch=uart_getchar();
+		lineendcnt--;
+	}
+	return(rval);
+}
+
 void terminalmode_next_line(void)
 {
         uart_sendchar('\x1B');
@@ -608,60 +643,27 @@ void terminalmode_next_line(void)
 
 void terminalmode(unsigned char iswin)
 {
-        unsigned char ch;
-        unsigned char i;
+	signed char i;
 	// Init terminal
 	uart_sendstr_p(terminal_init);
 	//
 	uart_sendstr_P("AvrUsb500 terminal mode\r\n");
-	i=1;
-	if (iswin){
-		i=2;
-	}
 	uart_sendstr_P("Enter SW Version Major [");
 	utoa(CONFIG_PARAM_SW_MAJOR,(char *)msg_buf, 10);
 	uart_sendstr((char *)msg_buf);
 	uart_sendstr_P("]: ");
-	ch=uart_getchar();
-	if (ch != '\r' && ch !='\n'){
-		uart_sendchar(ch); // echo number back to terminal
-	}
-	if ((ch > '0') && (ch < '9')){
-		CONFIG_PARAM_SW_MAJOR=ch - (unsigned char)'0';
-	}
-	// user just pressed return:
-	if (ch == '\r' || ch == '\n'){
-		i--;
-	}
-	// get \n or \r\n after a number was entered:
-	while(i){
-		ch=uart_getchar();
-		i--;
+	i=terminalmode_readnum(iswin);
+	if (i >=0){
+		CONFIG_PARAM_SW_MAJOR=(unsigned char)i;
 	}
 	terminalmode_next_line();
 	uart_sendstr_P("Enter SW Version Minor [");
 	utoa(CONFIG_PARAM_SW_MINOR,(char *)msg_buf, 10);
 	uart_sendstr((char *)msg_buf);
 	uart_sendstr_P("]: ");
-	i=1;
-	if (iswin){
-		i=2;
-	}
-	ch=uart_getchar();
-	if (ch != '\r' && ch !='\n'){
-		uart_sendchar(ch); // echo number back to terminal
-	}
-	if ((ch > '0') && (ch < '9')){
-		CONFIG_PARAM_SW_MINOR=ch - (unsigned char)'0';
-	}
-	// user just pressed return:
-	if (ch == '\r' || ch == '\n'){
-		i--;
-	}
-	// get \n or \r\n after a number was entered:
-	while(i){
-		ch=uart_getchar();
-		i--;
+	i=terminalmode_readnum(iswin);
+	if (i >=0){
+		CONFIG_PARAM_SW_MINOR=(unsigned char)i;
 	}
 	terminalmode_next_line();
 	eeprom_write_byte(EEPROM_MINOR, CONFIG_PARAM_SW_MINOR);
@@ -671,6 +673,9 @@ void terminalmode(unsigned char iswin)
 	utoa(CONFIG_PARAM_SW_MAJOR,(char *)msg_buf, 10);
 	uart_sendstr((char *)msg_buf);
 	uart_sendchar('.');
+	if (CONFIG_PARAM_SW_MINOR < 10){
+		uart_sendchar('0');
+	}
 	utoa(CONFIG_PARAM_SW_MINOR,(char *)msg_buf, 10);
 	uart_sendstr((char *)msg_buf);
 	uart_sendstr_P("\r\n");
