@@ -11,7 +11,7 @@
 #include "led.h"
 #include "avr_compat.h"
 
-void main(void)
+int main(void)
 {
         char ch;
         uart_init();
@@ -33,5 +33,6 @@ void main(void)
                         uart_sendstr_P("USAGE: 1 switch led on\n       0 switch led off\n");
                 }
         }
+	return(0);
 }
 
